searchData={"items":[{"type":"task","title":"mix benchmark","doc":"Run performance benchmarks for PipeAssign.\n\nThis task runs benchmarks comparing the performance of `assign_to/2` macro\nversus traditional assignment patterns.","ref":"Mix.Tasks.Benchmark.html"},{"type":"task","title":"Usage - mix benchmark","doc":"# Run quick comparison (default)\n    mix benchmark\n\n    # Run comprehensive benchmark suite\n    mix benchmark --full\n\n    # Run specific benchmark type\n    mix benchmark --type=hotpath\n    mix benchmark --type=complex\n    mix benchmark --type=string","ref":"Mix.Tasks.Benchmark.html#module-usage"},{"type":"task","title":"Options - mix benchmark","doc":"* `--full` - Run the comprehensive benchmark suite (takes longer)\n  * `--type=TYPE` - Run specific benchmark type (hotpath, complex, string, list, map)\n  * `--output=FILE` - Save HTML results to specified file","ref":"Mix.Tasks.Benchmark.html#module-options"},{"type":"task","title":"Benchmark Types - mix benchmark","doc":"* `quick` - Fast comparison of common patterns (default)\n  * `full` - Comprehensive test suite with multiple data sizes\n  * `hotpath` - Focus on performance-critical scenarios\n  * `complex` - Multi-step pipeline comparisons\n  * `string` - String processing benchmarks\n  * `list` - List processing benchmarks\n  * `map` - Map manipulation benchmarks","ref":"Mix.Tasks.Benchmark.html#module-benchmark-types"},{"type":"module","title":"PipeAssign","doc":"PipeAssign provides a macro for capturing intermediate values in Elixir pipe chains\nwithout breaking the flow or requiring separate assignment statements.","ref":"PipeAssign.html"},{"type":"module","title":"Problem and Solution - PipeAssign","doc":"Traditional Elixir code forces you to choose between clean pipes and intermediate access:\n\n    # Clean pipes, but no intermediate access\n    final_result = data |> transform() |> process() |> finalize()\n\n    # Intermediate access, but broken flow\n    step1 = data |> transform()\n    step2 = step1 |> process()\n    final_result = step2 |> finalize()\n\nPipeAssign solves this with `assign_to/2`:\n\n    import PipeAssign\n\n    data\n    |> transform()\n    |> assign_to(step1)  # Capture without breaking flow\n    |> process()\n    |> assign_to(step2)\n    |> finalize()\n    |> assign_to(result) # Assign to result variable\n\nIn Elixir `=` is a match operator. So we can match against it:\n\n    iex> import PipeAssign\n    iex> %{a: 1, b: 2}\n    ...> |> match_to(%{a: x})\n    %{b: 2, a: 1}\n    iex> x\n    1\n\n`assign_to/2` is the same as `match_to/2`:\n\n    # These are equivalent\n    value |> match_to(result)\n    value |> assign_to(result)\n\nSee the [README](https://hexdocs.pm/pipe_assign) for installation\ninstructions, examples, benchmarking results, and detailed usage guidance.","ref":"PipeAssign.html#module-problem-and-solution"},{"type":"macro","title":"PipeAssign.assign_to/2","doc":"This macro provides in-place assignments for pipes.\n\nThe variable will be assigned the piped value and the value continues through the pipe,\nallowing you to capture intermediate results without breaking the pipe flow or requiring\nseparate assignment statements.","ref":"PipeAssign.html#assign_to/2"},{"type":"macro","title":"Parameters - PipeAssign.assign_to/2","doc":"- `value` - The value to assign and return\n- `var` - A valid variable name to assign the value to","ref":"PipeAssign.html#assign_to/2-parameters"},{"type":"macro","title":"Examples - PipeAssign.assign_to/2","doc":"Import the module and use `assign_to/2` in your pipes:\n\n    iex> import PipeAssign\n    iex> [1, 2, 3]\n    ...> |> Enum.map(&(&1 * 2))\n    ...> |> Enum.sum()\n    ...> |> assign_to(result)\n    12\n    iex> result\n\nChain multiple assignments in a single pipe:\n\n    iex> import PipeAssign\n    iex> %{name: \"John\", age: 30}\n    ...> |> Map.put(:email, \"john@example.com\")\n    ...> |> assign_to(with_email)\n    ...> |> Map.put(:active, true)\n    ...> |> assign_to(complete)\n    ...> |> Map.keys()\n    ...> |> length()\n    ...> |> assign_to(result)\n    4\n    iex> result\n    4\n    iex> Map.get(with_email, :email)\n    \"john@example.com\"\n    iex> Map.get(complete, :active)\n    true\n\nWorks seamlessly with existing variables:\n\n    iex> import PipeAssign\n    iex> temp = \"initial\"\n    \"initial\"\n    iex> String.length(temp)\n    7\n    iex> \"hello world\"\n    ...> |> String.upcase()\n    ...> |> assign_to(temp)\n    ...> |> String.length()\n    11\n    iex> temp\n    \"HELLO WORLD\"\n\nUse without import for occasional assignments:\n\n    iex> [1, 2, 3, 4, 5]\n    ...> |> Enum.filter(&rem(&1, 2) == 0)\n    ...> |> PipeAssign.assign_to(evens)\n    [2, 4]\n    iex> evens\n    [2, 4]","ref":"PipeAssign.html#assign_to/2-examples"},{"type":"macro","title":"PipeAssign.match_to/2","doc":"`match_to/2` is the same as `assign_to/2`.","ref":"PipeAssign.html#match_to/2"},{"type":"macro","title":"Parameters - PipeAssign.match_to/2","doc":"- `value` - The value to match and return\n- `var` - A valid variable name to match the value to","ref":"PipeAssign.html#match_to/2-parameters"},{"type":"extras","title":"PipeAssign","doc":"# PipeAssign\n\n[![Hex.pm](https://img.shields.io/hexpm/v/pipe_assign.svg)](https://hex.pm/packages/pipe_assign)\n[![Documentation](https://img.shields.io/badge/docs-hexdocs-blue.svg)](https://hexdocs.pm/pipe_assign)\n[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)\n\nPipeAssign provides a macros for capturing intermediate values in Elixir pipe chains without breaking the flow or requiring separate assignment statements.","ref":"readme.html"},{"type":"extras","title":"⚠️ Warning - PipeAssign","doc":"This project was created for research purposes. To understand how `assign_to/2` and `match_to/2` will affect codebase:\n- What performance overhead would be?\n- What readability would be, worse or better?","ref":"readme.html#warning"},{"type":"extras","title":"The Problem - PipeAssign","doc":"Traditional Elixir code often forces you to choose between clean pipe flow and intermediate value access:\n\n```elixir\n# Clean pipes, but no intermediate access\nfinal_result = data |> transform() |> process() |> finalize()\n\n# Intermediate access, but broken flow\nstep1 = data |> transform()\nstep2 = step1 |> process()\nfinal_result = step2 |> finalize()\n```","ref":"readme.html#the-problem"},{"type":"extras","title":"The Solution - PipeAssign","doc":"PipeAssign bridges this gap by allowing you to capture values while maintaining the elegance of pipe operators:\n\n```elixir\nimport PipeAssign\n\ndata\n|> transform()\n|> assign_to(step1)  # Capture without breaking flow\n|> process()\n|> assign_to(step2)\n|> finalize()\n|> assign_to(result) # Assign to result variable\n```\n\nNow you have both clean pipe flow, access to step1, step2, result variables and no\nassignment before pipes.\n\nIn Elixir `=` is a match operator. So we can match against it:\n\n```elixir\n    iex> import PipeAssign\n    iex> %{a: 1, b: 2}\n    ...> |> match_to(%{a: x})\n    %{b: 2, a: 1}\n    iex> x\n    1\n```\n\n`assign_to/2` is the same as `match_to/2`:\n\n```elixir\n    # These are equivalent\n    value |> match_to(result)\n    value |> assign_to(result)\n```\n\nThis is just for readability.","ref":"readme.html#the-solution"},{"type":"extras","title":"Installation - PipeAssign","doc":"Add `pipe_assign` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:pipe_assign, \"~> 1.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - PipeAssign","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Basic Usage - PipeAssign","doc":"Import the module and use `assign_to/2` in your pipes:\n\n```elixir\nimport PipeAssign\n\n[1, 2, 3]\n|> Enum.map(&(&1 * 2))\n|> Enum.sum()\n|> assign_to(result)\n\n# result == 12\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Multiple Assignments - PipeAssign","doc":"Chain multiple assignments in a single pipe:\n\n```elixir\nimport PipeAssign\n\n%{name: \"John\", age: 30}\n|> Map.put(:email, \"john@example.com\")\n|> assign_to(with_email)\n|> Map.put(:active, true)\n|> assign_to(complete)\n|> Map.keys()\n|> length()\n|> assign_to(result)\n\n# result == 4\n# with_email == %{name: \"John\", age: 30, email: \"john@example.com\"}\n# complete == %{name: \"John\", age: 30, email: \"john@example.com\", active: true}\n```","ref":"readme.html#multiple-assignments"},{"type":"extras","title":"Without Import - PipeAssign","doc":"Use `require` to call macros with fully qualified name:\n\n```elixir\nrequire PipeAssign\n\n[1, 2, 3, 4, 5]\n|> Enum.filter(&rem(&1, 2) == 0)\n|> PipeAssign.assign_to(evens)\n\n# evens == [2, 4]\n```","ref":"readme.html#without-import"},{"type":"extras","title":"Examples - PipeAssign","doc":"","ref":"readme.html#examples"},{"type":"extras","title":"Data Processing Pipeline - PipeAssign","doc":"```elixir\nimport PipeAssign\n\ndef process_user_data(raw_data) do\n  raw_data\n  |> Jason.decode!()\n  |> assign_to(parsed_json)\n  |> normalize_keys()\n  |> assign_to(normalized)\n  |> validate_required_fields()\n  |> assign_to(validated)\n  |> save_to_database()\n  |> assign_to(result)\n\n  Logger.info(\"Processed user data\", %{\n    raw_size: byte_size(raw_data),\n    parsed_keys: Map.keys(parsed_json),\n    normalized_count: map_size(normalized),\n    validation_status: validated.status\n  })\n\n  result\nend\n```","ref":"readme.html#data-processing-pipeline"},{"type":"extras","title":"API Response Processing - PipeAssign","doc":"```elixir\nimport PipeAssign\n\ndef fetch_and_process_posts(user_id) do\n  user_id\n  |> fetch_user_posts()\n  |> assign_to(raw_posts)\n  |> Enum.filter(&(&1.published))\n  |> assign_to(published_posts)\n  |> Enum.sort_by(&(&1.created_at), :desc)\n  |> assign_to(sorted_posts)\n  |> Enum.take(10)\n  |> format_for_api()\n  |> tap(fn _ ->\n    Analytics.track(\"posts_fetched\", %{\n      user_id: user_id,\n      total_posts: length(raw_posts),\n      published_posts: length(published_posts),\n      returned_posts: length(sorted_posts)\n    })\n  end)\nend\n```","ref":"readme.html#api-response-processing"},{"type":"extras","title":"Performance Impact - PipeAssign","doc":"Based on benchmarks with MacBook Air M1 16GB, the overhead are within the margin of error.","ref":"readme.html#performance-impact"},{"type":"extras","title":"Benchmarking - PipeAssign","doc":"PipeAssign includes a comprehensive benchmarking suite to help you understand the performance implications in your specific use cases.","ref":"readme.html#benchmarking"},{"type":"extras","title":"Running Benchmarks - PipeAssign","doc":"```bash\n# Quick comparison (recommended for most users)\nmix benchmark\n\n# Comprehensive benchmark suite (takes longer)\nmix benchmark --full\n\n# Specific benchmark types\nmix benchmark --type=hotpath    # Performance-critical scenarios\nmix benchmark --type=complex    # Multi-step pipelines\nmix benchmark --type=string     # String processing\nmix benchmark --type=list       # List operations\nmix benchmark --type=map        # Map manipulations\n```","ref":"readme.html#running-benchmarks"},{"type":"extras","title":"Understanding Results - PipeAssign","doc":"The benchmarks compare `assign_to/2` against traditional assignment patterns across various scenarios. All performance measurements were conducted on MacBook Air M1 16GB running macOS.\n\n- **Hot path scenarios**: Simple operations where overhead is most visible\n- **Complex pipelines**: Multi-step transformations where overhead is proportionally smaller\n- **Different data sizes**: Small, medium, and large datasets\n- **Various data types**: Lists, strings, maps, and mixed operations","ref":"readme.html#understanding-results"},{"type":"extras","title":"Sample Results - PipeAssign","doc":"Latest benchmark results (MacBook Air M1 16GB, macOS) show:\n\n```\nName                           ips        average     deviation      median         99th %\nHot Path Traditional          7.84 M      127.63 ns   ±10284.16%     125 ns         125 ns\nHot Path assign_to/2          7.83 M      127.72 ns    ±9866.55%     125 ns         125 ns\n\nString assign_to/2           21.44 K       46.65 μs    ±10.07%       46.96 μs       57.04 μs\nString Traditional           21.34 K       46.87 μs     ±9.62%       47.29 μs       57.08 μs\n\nComplex assign_to/2          25.47 K       39.27 μs    ±11.90%       40.21 μs          52 μs\nComplex Traditional          25.38 K       39.40 μs    ±12.26%       40.42 μs          52 μs\n\nList Traditional             54.28 K       18.42 μs    ±22.83%       18.21 μs       20.96 μs\nList assign_to/2             54.05 K       18.50 μs    ±22.93%       18.25 μs       21.38 μs\n\nMap Traditional             239.71 K        4.17 μs    ±204.30%       4.04 μs        6.04 μs\nMap assign_to/2             239.09 K        4.18 μs    ±200.79%       4.08 μs        5.96 μs\n\nComparison:\nHot Path Traditional        7.84 M\nHot Path assign_to/2        7.83 M - 1.00x slower +0.0906 ns\n\nString assign_to/2          21.44 K\nString Traditional          21.34 K - 1.00x slower +0.22 μs\n\nComplex assign_to/2         25.47 K\nComplex Traditional         25.38 K - 1.00x slower +0.135 μs\n\nList Traditional            54.28 K\nList assign_to/2            54.05 K - 1.00x slower +0.0780 μs\n\nMap Traditional             239.71 K\nMap assign_to/2             239.09 K - 1.00x slower +0.0108 μs\n```","ref":"readme.html#sample-results"},{"type":"extras","title":"Testing - PipeAssign","doc":"The library includes comprehensive test coverage. Run the tests with:\n\n```bash\nmix test\n```\n\nTo check test coverage:\n\n```bash\nmix test --cover\n```","ref":"readme.html#testing"},{"type":"extras","title":"Support Matrix - PipeAssign","doc":"Tests automatically run against a matrix of OTP and Elixir Versions, see the [ci.yml](https://github.com/pertsevds/pipe_assign/tree/main/.github/workflows/ci.yml) for details.\n\n| OTP \\ Elixir | 1.15 | 1.16 | 1.17 | 1.18 |\n|:------------:|:----:|:----:|:----:|:----:|\n| 25           | ✅  | ✅  | ✅  | ✅  |\n| 26           | ✅  | ✅  | ✅  | ✅  |\n| 27           | N/A  | N/A  | ✅  | ✅  |","ref":"readme.html#support-matrix"},{"type":"extras","title":"Documentation - PipeAssign","doc":"Full documentation is available at [https://hexdocs.pm/pipe_assign](https://hexdocs.pm/pipe_assign).","ref":"readme.html#documentation"},{"type":"extras","title":"License - PipeAssign","doc":"This project is licensed under the Apache License 2.0 - see the [LICENSE](LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS","ref":"license.html"},{"type":"extras","title":"NOTICE","doc":"Copyright 2025 Dmitriy Pertsev, Derek Zhou\n\n  Licensed under the Apache License, Version 2.0 (the \"License\");\n  you may not use this file except in compliance with the License.\n  You may obtain a copy of the License at\n\n      http://www.apache.org/licenses/LICENSE-2.0\n\n  Unless required by applicable law or agreed to in writing, software\n  distributed under the License is distributed on an \"AS IS\" BASIS,\n  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n  See the License for the specific language governing permissions and\n  limitations under the License.\n\n==========================================================================\n\nDependencies are externally maintained and have their own licenses; I\nrecommend you read them as their terms may differ from the terms above.","ref":"notice.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}